@@ -15,15 +15,13 @@ class RewriteTupleAssign(NodeTransformer):
             return [node]
         uid = self.unique_id
         self.unique_id += 1
-        assignments = [
-            Assign([Name(f"__tuple{uid}__", Store())], self.visit(node.value))
-        ]
+        assignments = [Assign([Name(f"{uid}_tup", Store())], self.visit(node.value))]
         for i, t in enumerate(node.targets[0].elts):
             assignments.append(
                 Assign(
                     [t],
                     Subscript(
-                        value=Name(f"__tuple{uid}__", Load()),
+                        value=Name(f"{uid}_tup", Load()),
                         slice=Index(value=Constant(i)),
                         ctx=Load(),
                     ),
